@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 from plone.app.contentrules import handlers
 from unittest import TestCase
 from zope.lifecycleevent import ObjectAddedEvent
@@ -6,12 +5,10 @@ from zope.lifecycleevent import ObjectRemovedEvent
 
 
 class TestModifyAction(TestCase):
-
     def setUp(self):
         self.called = False
 
         def register_call(testcase):
-
             def inner_register_call(event):
                 testcase.called = True
 
@@ -25,15 +22,17 @@ class TestModifyAction(TestCase):
         self.called = False
 
     def testIgnoreAddedEvents(self):
-        class Content(object):
+        class Content:
             __parent__ = None
             __name__ = None
+
         handlers.modified(ObjectAddedEvent(Content()))
         self.assertFalse(self.called)
 
     def testIgnoreDeletedEvents(self):
-        class Content(object):
+        class Content:
             __parent__ = None
             __name__ = None
+
         handlers.modified(ObjectRemovedEvent(Content()))
         self.assertFalse(self.called)
